@@ -299,7 +299,7 @@ def PySconsSetup(args=ARGUMENTS, tools=['default', PYTOOL()]):
     except: basename = None
 
     bn = list(os.path.split(basename))
-    env.SConsignFile(*(os.path.join([".."] * N + bn + [".sconsign"])))
+    env.SConsignFile(os.path.join(*([".."] * N + bn + [".sconsign"])))
 
     ftargets = [t + ".force" for t in targets]
     if reduce(lambda a,b: a&b, (os.path.exists(t) for t in ftargets)):
